@@ -54,6 +54,8 @@ b"\x1b[A": KEY_UP,
 b"\x1b[B": KEY_DOWN,
 b"\x1b[D": KEY_LEFT,
 b"\x1b[C": KEY_RIGHT,
+b"\x1b[H": KEY_HOME,
+b"\x1b[F": KEY_END,
 b"\x1bOH": KEY_HOME,
 b"\x1bOF": KEY_END,
 b"\x1b[1~": KEY_HOME,
